@@ -53,7 +53,7 @@ class proxy_factory {
 public:
 	proxy_factory();
 	~proxy_factory();
-	vector<string> get_proxies(string url);
+	vector<string> get_proxies(const string &url);
 
 private:
 	void lock();
@@ -187,7 +187,7 @@ proxy_factory::~proxy_factory() {
 }
 
 
-vector<string> proxy_factory::get_proxies(string realurl) {
+vector<string> proxy_factory::get_proxies(const string &realurl) {
 	vector<string>             response;
 
 	// Check to make sure our url is valid
@@ -244,7 +244,7 @@ void proxy_factory::check_network_topology() {
 			vector<wpad_extension*> wpads = this->mm.get_extensions<wpad_extension>();
 			for (vector<wpad_extension*>::iterator j=wpads.begin() ; j != wpads.end() ; j++)
 				(*j)->rewind();
-			if (this->pac) delete this->pac;
+			if (this->pac) delete[] this->pac;
 			this->pac = NULL;
 			break;
 		}
@@ -313,7 +313,7 @@ bool proxy_factory::expand_wpad(const url &confurl)
 		rtv = true;
 		/* If the config has just changed from PAC to WPAD, clear the PAC */
 		if (!this->wpad) {
-			if (this->pac)    delete this->pac;
+			if (this->pac)    delete[] this->pac;
 			if (this->pacurl) delete this->pacurl;
 			this->pac    = NULL;
 			this->pacurl = NULL;
@@ -381,7 +381,7 @@ bool proxy_factory::expand_pac(url &confurl)
 		if (this->pac) {
 			if (this->pacurl->to_string() != confurl.to_string()) {
 				delete this->pacurl;
-				delete this->pac;
+				delete[] this->pac;
 				this->pacurl = NULL;
 				this->pac    = NULL;
 			}
@@ -416,7 +416,9 @@ void proxy_factory::run_pac(url &realurl, const url &confurl, vector<string> &re
 
 		/* Run the PAC, but only try one PACRunner */
 		if (debug) cerr << "Using pacrunner: " << typeid(*pacrunners[0]).name() << endl;
-		string pacresp = pacrunners[0]->get(this->pac, this->pacurl->to_string())->run(realurl);
+		pacrunner* runner = pacrunners[0]->get(this->pac, this->pacurl->to_string());
+		string pacresp = runner->run(realurl);
+		delete runner;
 		if (debug) cerr << "Pacrunner returned: " << pacresp << endl;
 		format_pac_response(pacresp, response);
 	}
@@ -424,7 +426,7 @@ void proxy_factory::run_pac(url &realurl, const url &confurl, vector<string> &re
 
 void proxy_factory::clear_cache() {
 	this->wpad = false;
-	if (this->pac)    { delete this->pac;    this->pac = NULL; }
+	if (this->pac)    { delete[] this->pac;  this->pac = NULL; }
 	if (this->pacurl) { delete this->pacurl; this->pacurl = NULL; }
 }
 
@@ -483,6 +485,16 @@ extern "C" DLL_PUBLIC char** px_proxy_factory_get_proxies(struct pxProxyFactory_
 	return retval;
 }
 
+extern "C" DLL_PUBLIC void px_proxy_factory_free_proxies(char ** const proxies) {
+	if (!proxies)
+		return;
+
+	for (size_t i = 0; proxies[i]; ++i)
+		free(proxies[i]);
+
+	free(proxies);
+}
+
 extern "C" DLL_PUBLIC void px_proxy_factory_free(struct pxProxyFactory_ *self) {
 	delete self;
 }
